"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var application = require("application");
var GSMPlacePicker = com.google.android.gms.location.places.ui.PlacePicker;
var Intent = android.content.Intent;
var Activity = android.app.Activity;
function toSelectedPlace(nativePlace) {
    var regex = /.*name=(.*?),\saddress=(.*?),/g;
    var m = regex.exec(nativePlace.toString());
    return {
        nativePlace: nativePlace,
        id: nativePlace.getId(),
        name: m[1],
        address: m[2],
        latitude: nativePlace.getLatLng().latitude,
        longitude: nativePlace.getLatLng().longitude
    };
}
var PlacePicker = (function () {
    function PlacePicker(initCoords) {
        if (initCoords === void 0) { initCoords = { latitude: 37.788204, longitude: -122.411937 }; }
        this.initCoords = initCoords;
        var LatLng = com.google.android.gms.maps.model.LatLng;
        var LatLngBounds = com.google.android.gms.maps.model.LatLngBounds;
        this._builder = new GSMPlacePicker.IntentBuilder();
        var center = new LatLng(initCoords.latitude, initCoords.longitude);
        var northEast = new LatLng(center.latitude + 0.001, center.longitude + 0.001);
        var southWest = new LatLng(center.latitude - 0.001, center.longitude - 0.001);
        var viewport = new LatLngBounds(southWest, northEast);
        this._builder.setLatLngBounds(viewport);
    }
    PlacePicker.iosProvideAPIKey = function (key) {
    };
    PlacePicker.prototype.present = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            var PLACE_PICKER_REQUEST = 34258;
            var context = application.android.foregroundActivity;
            application.android.on(application.AndroidApplication.activityResultEvent, onResult, _this);
            function onResult(args) {
                var requestCode = args.requestCode;
                var resultCode = args.resultCode;
                var data = args.intent;
                if (requestCode == PLACE_PICKER_REQUEST) {
                    application.android.off(application.AndroidApplication.activityResultEvent, onResult, this);
                    if (resultCode == Activity.RESULT_OK) {
                        var place = GSMPlacePicker.getPlace(data, context);
                        resolve(toSelectedPlace(place));
                    }
                    else if (resultCode == Activity.RESULT_CANCELED) {
                        resolve(null);
                    }
                    else {
                        reject(new Error("Place picker activity result code " + resultCode));
                    }
                }
            }
            try {
                var intent = _this._builder.build(context);
                application.android.foregroundActivity.startActivityForResult(intent, PLACE_PICKER_REQUEST);
            }
            catch (e) {
                var en = e.nativeException;
                if (en) {
                    var apiAvailability = com.google.android.gms.common.GoogleApiAvailability.getInstance();
                    var errorcode = apiAvailability.isGooglePlayServicesAvailable(context);
                    apiAvailability.getErrorDialog(context, errorcode, 0).show();
                }
                application.android.off(application.AndroidApplication.activityResultEvent, onResult, _this);
            }
        });
    };
    return PlacePicker;
}());
exports.PlacePicker = PlacePicker;
//# sourceMappingURL=place-picker.android.js.map