"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var frame_1 = require("ui/frame");
function toSelectedPlace(nativePlace) {
    if (nativePlace == null) {
        return null;
    }
    return {
        nativePlace: nativePlace,
        id: nativePlace.placeID,
        name: nativePlace.name,
        address: nativePlace.formattedAddress,
        latitude: nativePlace.coordinate.latitude,
        longitude: nativePlace.coordinate.longitude,
    };
}
var PlacePickerDelegate = (function (_super) {
    __extends(PlacePickerDelegate, _super);
    function PlacePickerDelegate() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PlacePickerDelegate.prototype.placePickerDidCancel = function (viewController) {
        viewController.dismissViewControllerAnimatedCompletion(true, null);
        this._placePicker.done(null);
    };
    PlacePickerDelegate.prototype.placePickerDidFailWithError = function (viewController, error) {
        viewController.dismissViewControllerAnimatedCompletion(true, null);
        this._placePicker.error(error);
    };
    PlacePickerDelegate.prototype.placePickerDidPickPlace = function (viewController, place) {
        viewController.dismissViewControllerAnimatedCompletion(true, null);
        this._placePicker.done(toSelectedPlace(place));
    };
    PlacePickerDelegate.prototype.initWith = function (p) {
        this._placePicker = p;
        return this;
    };
    return PlacePickerDelegate;
}(NSObject));
PlacePickerDelegate.ObjCProtocols = [GMSPlacePickerViewControllerDelegate];
exports.PlacePickerDelegate = PlacePickerDelegate;
var PlacePicker = (function () {
    function PlacePicker(initCoords) {
        if (initCoords === void 0) { initCoords = { latitude: 37.788204, longitude: -122.411937 }; }
        this.initCoords = initCoords;
        var center = CLLocationCoordinate2DMake(initCoords.latitude, initCoords.longitude);
        var northEast = CLLocationCoordinate2DMake(center.latitude + 0.001, center.longitude + 0.001);
        var southWest = CLLocationCoordinate2DMake(center.latitude - 0.001, center.longitude - 0.001);
        var viewport = new GMSCoordinateBounds({ coordinate: northEast, coordinate2: southWest });
        var config = new GMSPlacePickerConfig({ viewport: viewport });
        this._gsmpp = new GMSPlacePickerViewController({ config: config });
        this._gsmpp.delegate = new PlacePickerDelegate().initWith(this);
    }
    Object.defineProperty(PlacePicker.prototype, "currentPage", {
        get: function () {
            return frame_1.topmost().currentPage;
        },
        enumerable: true,
        configurable: true
    });
    PlacePicker.iosProvideAPIKey = function (key) {
        GMSPlacesClient.provideAPIKey(key);
        GMSServices.provideAPIKey(key);
    };
    PlacePicker.prototype.present = function () {
        var _this = this;
        if (this._resolve || this._reject) {
            return Promise.reject(new Error("Selection is allready in progress..."));
        }
        else {
            return new Promise(function (resolve, reject) {
                _this._resolve = resolve;
                _this._reject = reject;
                _this.currentPage.ios.presentViewControllerAnimatedCompletion(_this._gsmpp, true, null);
            });
        }
    };
    PlacePicker.prototype.error = function (error) {
        this._reject(new Error("Place picker error: " + error));
        this._reject = null;
        this._resolve = null;
    };
    PlacePicker.prototype.done = function (place) {
        this._resolve(place);
        this._reject = null;
        this._resolve = null;
    };
    return PlacePicker;
}());
exports.PlacePicker = PlacePicker;
//# sourceMappingURL=place-picker.ios.js.map